import objectdraw.*;
import java.net.*;
import java.io.*;
import java.util.*;

/**
 * A simple class providing a interface to send network messages to a server.
 */
public class NetConnection {

    private static final int PORT = 1101;

    private BufferedReader input;

    private PrintWriter output;

    private boolean connected = false;

    /**
     * Construct a new connection to a server;
     */
    public NetConnection(String server) {
        try {
            Socket socket = new Socket(server, PORT);
            input = new BufferedReader(new InputStreamReader(socket.getInputStream()));
            output = new PrintWriter(new OutputStreamWriter(socket.getOutputStream()), true);
            connected = true;
        } catch (IOException e) {
            System.out.println("Connection error: " + e.getMessage());
        }
    }

    /**
     * Check whether the connection is active;
     */
    public boolean isConnected() {
        return connected;
    }

    /**
     * Send a message to the server and returns the response.
     * If the connection is not open or the message cannot be sent, returns null;
     */
    public synchronized String sendMessage(String message) {
        if (!connected) {
            return null;
        }
        try {
            output.println(message);
            return input.readLine();
        } catch (IOException e) {
            System.out.println("Couldn't send message: " + e.getMessage());
            connected = false;
            return null;
        }
    }

}
